@@ -1,6 +1,6 @@
 use bae::FromAttributes;
+use convert_case::{Case, Casing};
 use proc_macro2::{Ident, Span};
-use quote::format_ident;
 use syn::{Error, Expr, Type};
 
 pub trait ErrorCallSite {
@@ -19,8 +19,11 @@ impl ErrorCallSite for Error {
 }
 
 pub trait AsyncDebugCommon {
-    fn get_async_debug_ident(ident: &Ident) -> Ident {
-        format_ident!("{}AsyncDebug", ident)
+    fn get_async_debug_mod_ident(ident: &Ident) -> Ident {
+        Ident::new(
+            &format!("async_debug_{}", ident.to_string().to_case(Case::Snake)),
+            ident.span(),
+        )
     }
 }
 
